@@ -159,7 +159,6 @@ static HKL latin_locale = NULL;
 #endif
 
 static gboolean in_ime_composition = FALSE;
-static gboolean resizing = FALSE;
 static UINT     resize_timer;
 
 static int debug_indent = 0;
@@ -2054,10 +2053,18 @@ resize_timer_proc (HWND     hwnd,
 		   UINT     id,
 		   DWORD    time)
 {
-  if (resizing)
+  if (_sizemove_in_progress)
     handle_stuff_while_moving_or_resizing ();
 }
 
+static void
+handle_display_change (void)
+{
+  _gdk_monitor_init ();
+  _gdk_root_window_size_init ();
+  g_signal_emit_by_name (_gdk_screen, "size_changed");
+}
+
 static gboolean
 gdk_event_translate (GdkDisplay *display,
 		     MSG        *msg,
@@ -2968,12 +2975,12 @@ gdk_event_translate (GdkDisplay *display,
       break;
 
     case WM_ENTERSIZEMOVE:
-      resizing = TRUE;
+      _sizemove_in_progress = TRUE;
       resize_timer = SetTimer (NULL, 0, 20, resize_timer_proc);
       break;
 
     case WM_EXITSIZEMOVE:
-      resizing = FALSE;
+      _sizemove_in_progress = FALSE;
       KillTimer (NULL, resize_timer);
       break;
 
@@ -2981,7 +2988,7 @@ gdk_event_translate (GdkDisplay *display,
       /* Once we've entered the moving or sizing modal loop, we won't
        * return to the main loop until we're done sizing or moving.
        */
-      if (resizing &&
+      if (_sizemove_in_progress &&
 	 GDK_WINDOW_TYPE (window) != GDK_WINDOW_CHILD &&
 	 !GDK_WINDOW_DESTROYED (window))
 	{
@@ -3278,6 +3285,11 @@ gdk_event_translate (GdkDisplay *display,
       return_val = TRUE;
       break;
 
+    case WM_DISPLAYCHANGE:
+      handle_display_change ();
+      break;
+      
+
 #ifdef HAVE_WINTAB
       /* Handle WINTAB events here, as we know that gdkinput.c will
        * use the fixed WT_DEFBASE as lcMsgBase, and we thus can use the
