@@ -2014,18 +2014,33 @@ gtk_tree_store_swap (GtkTreeStore *tree_store,
   gtk_tree_path_up (path_a);
   gtk_tree_path_up (path_b);
 
-  if (gtk_tree_path_compare (path_a, path_b))
+  if (gtk_tree_path_get_depth (path_a) == 0
+      || gtk_tree_path_get_depth (path_b) == 0)
     {
-      gtk_tree_path_free (path_a);
-      gtk_tree_path_free (path_b);
-
-      g_warning ("Given childs are not in the same level\n");
-      return;
+      if (gtk_tree_path_get_depth (path_a) != gtk_tree_path_get_depth (path_b))
+        {
+          gtk_tree_path_free (path_a);
+          gtk_tree_path_free (path_b);
+                                                                                
+          g_warning ("Given children are not in the same level\n");
+          return;
+        }
+      parent_node = G_NODE (tree_store->root);
+    }
+  else
+    {
+      if (gtk_tree_path_compare (path_a, path_b))
+        {
+          gtk_tree_path_free (path_a);
+          gtk_tree_path_free (path_b);
+                                                                                
+          g_warning ("Given children don't have a common parent\n");
+          return;
+        }
+      gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &parent,
+                               path_a);
+      parent_node = G_NODE (parent.user_data);
     }
-
-  gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &parent, path_a);
-  parent_node = G_NODE (parent.user_data);
-
   gtk_tree_path_free (path_b);
 
   /* old links which we have to keep around */
@@ -2095,7 +2110,8 @@ gtk_tree_store_swap (GtkTreeStore *tree_store,
       order[i] = i;
 
   gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store), path_a,
-				 &parent, order);
+				 parent_node == tree_store->root 
+				 ? NULL : &parent, order);
   gtk_tree_path_free (path_a);
   g_free (order);
 }
@@ -2302,7 +2318,8 @@ gtk_tree_store_move (GtkTreeStore *tree_store,
       parent->children = node;
 
       node->next = tmp;
-      tmp->prev = node;
+      if (tmp) 
+	tmp->prev = node;
 
       handle_b = FALSE;
     }
@@ -2393,12 +2410,17 @@ gtk_tree_store_move (GtkTreeStore *tree_store,
     }
 
   if (depth)
-    path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter);
+    {
+      path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter);
+      gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store),
+				     path, &parent_iter, order);
+    }
   else
-    path = gtk_tree_path_new ();
-
-  gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store),
-				 path, &parent_iter, order);
+    {
+      path = gtk_tree_path_new ();
+      gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store),
+				     path, NULL, order);
+    }
 
   gtk_tree_path_free (path);
   if (position)
